lxm3.xm\_cluster.Slurm
======================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: Slurm

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Slurm.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Slurm.requirements
      ~Slurm.resources
      ~Slurm.walltime
      ~Slurm.singularity_options
      ~Slurm.log_directory
      ~Slurm.modules
      ~Slurm.exclusive
      ~Slurm.partition
      ~Slurm.extra_directives
      ~Slurm.skip_directives
   
   